import time
import pymysql
from selenium import webdriver
from selenium.webdriver.firefox.options import Options
from selenium.webdriver.common.by import By
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
from datetime import datetime

# Configurações do Selenium WebDriver
options = Options()
options.headless = True

# Desativar o carregamento de imagens
options.set_preference("permissions.default.image", 2)
# Bloquear o carregamento de CSS
options.set_preference("permissions.default.stylesheet", 2)
# Bloquear o carregamento de JavaScript
options.set_preference("javascript.enabled", False)

driver = webdriver.Firefox(options=options)

# Conexão com o banco de dados MySQL
db_host = "187.45.179.18"
db_user = "colibexcom_user"
db_pass = "wo3dZ}@*eS$%"
db_name = "colibexcom_banco"

# Conectando ao banco de dados
conn = pymysql.connect(host=db_host, user=db_user, password=db_pass, database=db_name)
cursor = conn.cursor()

def abrir_fechar_aba(url, driver):
    janela_inicial = driver.window_handles[0]
    driver.execute_script(f"window.open('{url}');")
    WebDriverWait(driver, 10).until(EC.number_of_windows_to_be(2))
    nova_janela = [x for x in driver.window_handles if x != janela_inicial][0]
    driver.switch_to.window(nova_janela)
    WebDriverWait(driver, 60).until(EC.presence_of_element_located((By.TAG_NAME, 'title')))
    body_element = driver.find_element(By.TAG_NAME, 'body')
    conteudo_body = body_element.get_attribute('innerHTML')
    
    if "Google Tag Manager" not in conteudo_body:
        print("A palavra 'Google Tag Manager' não foi encontrada no HTML. Pausando a execução.")
        driver.quit()  # Fechar o navegador e interromper a execução
        quit()  # Parar completamente a execução do programa
        return None
    
    if "Ocorreu um erro" in conteudo_body:
        print("A palavra 'Ocorreu um erro'  foi encontrada no HTML. Pausando a execução.")
        driver.quit()  # Fechar o navegador e interromper a execução
        quit()  # Parar completamente a execução do programa
        return None
    
    driver.close()
    driver.switch_to.window(janela_inicial)
    return conteudo_body

def atualizar_banco(id_registro, html):
    try:
        # Obtém a data e hora atual
        data_hora_atual = datetime.now()

        # Formata a data e hora no formato desejado
        data_hora_formatada = data_hora_atual.strftime("%d/%m/%Y %H:%M:%S")
        # Atualizar o registro no banco de dados com o HTML extraído
        sql_update = "UPDATE `z_json_caixa` SET `html` = %s WHERE `id` = %s"
        cursor.execute(sql_update, (data_hora_formatada+html, id_registro))
        conn.commit()
        print("Registro atualizado no banco de dados.")
    except Exception as e:
        conn.rollback()
        print("Erro ao atualizar o registro no banco de dados:", e)

def iniciar(driver):
    # Consulta SQL para obter o próximo registro não atualizado
    sql_select = "SELECT `id`, `id_cidade`, `id_imovel_caixa`, `uf`, `modalidade`, `json`, `data_create`, `data_update` FROM `z_json_caixa` WHERE atualizou = '0' AND `html` != '' AND id_imovel_caixa!='' ORDER BY RAND() LIMIT 1;"

    try:
        # Executando a consulta SQL
        cursor.execute(sql_select)
        result = cursor.fetchone()  # Fetchone para obter apenas um resultado

        # Verificando se há resultados
        if result:

            id = result[0]
            sql = f"UPDATE `z_json_caixa` SET `atualizou` = '1' WHERE `id` = {id}"
            print(sql)
            cursor.execute(sql)
            conn.commit()

            id_imovel_caixa = result[2]
            link = f"https://venda-imoveis.caixa.gov.br/sistema/detalhe-imovel.asp?hdnOrigem=index&hdnimovel={id_imovel_caixa}"
            html = abrir_fechar_aba(link, driver)
            # Verificar se o HTML não é nulo nem uma string vazia antes de atualizar o banco de dados
            if html is not None and html.strip():
                # Atualizar o registro no banco de dados com o HTML extraído
                atualizar_banco(result[0], html)
            else:
                print("HTML extraído está nulo ou vazio. Não será atualizado no banco de dados.")
        else:
            print("Nenhum imóvel não atualizado encontrado.")
            # Atualizar o campo `atualizou` para 0 quando nenhum imóvel não atualizado for encontrado
            cursor.execute("UPDATE `z_json_caixa` SET `atualizou` = '0' ")
            conn.commit()
            print("Campo 'atualizou' atualizado para 0.")

    except Exception as e:
        print("Erro ao executar a consulta SQL:", e)
        driver.quit()  # Fechar o navegador e interromper a execução
        quit()  # Parar completamente a execução do programa
        return

# Tempo de execução desejado em segundos (5 minutos = 300 segundos)
tempo_execucao = 300000000000000
tempo_inicial = time.time()

# Loop para continuar executando até que o tempo de execução expire
while (time.time() - tempo_inicial) < tempo_execucao:
    iniciar(driver)

# Encerrar o navegador e a conexão com o banco de dados após o término do loop
driver.quit()
conn.close()